#import <OSLog/OSLog.h>
#import "AppDelegate.h"
#import "SINCallKitMediator.h"
#import "LoginViewController.h"

static os_log_type_t osLogTypeFrom(SINLogSeverity severity);

@interface AppDelegate ()
@property (nonatomic, readwrite, strong) SINCallKitMediator *callKitMediator;
@property (nonatomic, readwrite, strong) os_log_t customLog;
@end

@implementation AppDelegate

- (BOOL)application:(UIApplication *)application
    didFinishLaunchingWithOptions:(nullable NSDictionary<UIApplicationLaunchOptionsKey, id> *)launchOptions {
  self.customLog = os_log_create("com.sinch.sdk.app", "AppDelegate");
  os_log(self.customLog, "didFinishLaunchingWithOptions:");

  [Sinch setLogCallback:^(SINLogSeverity severity, NSString *area, NSString *message, NSDate *timestamp) {
    os_log_t logt = os_log_create("com.sinch.sdk.app", area.UTF8String);
    os_log_with_type(logt, osLogTypeFrom(severity), "%{public}@", message);
  }];

  self.callKitMediator = [[SINCallKitMediator alloc] init];

  if ([self.window.rootViewController isKindOfClass:LoginViewController.class]) {
    LoginViewController *lvc = (LoginViewController *)self.window.rootViewController;
    lvc.callKitMediator = self.callKitMediator;
  }

  return YES;
}

@end

static os_log_type_t osLogTypeFrom(SINLogSeverity severity) {
  switch (severity) {
    case SINLogSeverityInfo:
      return OS_LOG_TYPE_DEFAULT;
    case SINLogSeverityCritical:
      return OS_LOG_TYPE_FAULT;
    case SINLogSeverityWarn:
      return OS_LOG_TYPE_DEFAULT;
    case SINLogSeverityTrace:
      return OS_LOG_TYPE_DEBUG;
    default:
      return OS_LOG_TYPE_DEFAULT;
  }
}
