#import "CallViewController.h"
#import "CallViewController+UI.h"
#import "SINCallKitMediator.h"

@interface CallViewController () <SINCallKitMediatorObserver>
@end

@implementation CallViewController

- (id<SINClient>)client {
  return self.callKitMediator.client;
}

- (void)setCallKitMediator:(SINCallKitMediator *)callKitMediator {
  _callKitMediator = callKitMediator;
  [_callKitMediator addObserver:self];
}

#pragma mark - UIViewController Cycle

- (void)viewDidLoad {
  [super viewDidLoad];

  NSAssert(self.callKitMediator != nil, @"self.callKitMediator must not be nil here", @"");
  NSAssert(self.callKitMediator.client != nil, @"self.callKitMediator.client must not be nil here", @"");

  if ([self.call direction] == SINCallDirectionOutgoing) {
    [self setCallStatusText:@"calling..."];
  }
}

- (void)viewWillAppear:(BOOL)animated {
  [super viewWillAppear:animated];
  self.remoteUsername.text = [self.call remoteUserId];
}

#pragma mark - Call Actions

- (IBAction)hangup:(id)sender {
  [self.callKitMediator endCall:self.call];
}

- (void)onDurationTimer:(NSTimer *)unused {
  NSInteger duration = (NSInteger)[[NSDate date] timeIntervalSinceDate:[[self.call details] establishedTime]];
  [self setDuration:duration];
}

#pragma mark - SINCallDelegate

- (void)callDidProgress:(id<SINCall>)call {
  [self setCallStatusText:@"ringing..."];
  [[self.client audioController] startPlayingSoundFile:[self pathForSound:@"ringback.wav"] loop:YES error:nil];
}

- (void)callDidEstablish:(id<SINCall>)call {
  [self startCallDurationTimerWithSelector:@selector(onDurationTimer:)];
  [[self.client audioController] stopPlayingSoundFile];
}

- (void)callDidEnd:(id<SINCall>)call {
  [self.callKitMediator removeObserver:self];

  [self stopCallDurationTimer];
  [[self.client audioController] stopPlayingSoundFile];
  [self dismiss];
}

#pragma mark - Sounds

- (NSString *)pathForSound:(NSString *)soundName {
  return [[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:soundName];
}

@end
