#import <Foundation/Foundation.h>
#import <CallKit/CallKit.h>
#import <Foundation/Foundation.h>
#import <OSLog/OSLog.h>
#import <Sinch/Sinch.h>
#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN

@protocol SINCallKitMediatorObserver <SINCallDelegate>
@end

typedef void (^VoidCompletion)(void);
typedef void (^ErrorCompletion)(NSError *_Nullable);
typedef void (^CallStartedCompletion)(id<SINCall> _Nullable, NSError *_Nullable);

/// This class shows one of the ways of Sinch SDK intagration with CallKit
@interface SINCallKitMediator : NSObject

/// Logged in instance of sinch client. nil if no instance was created
@property (nonatomic, readonly, strong) _Nullable id<SINClient> client;

- (instancetype)init;

/// Call to create sinch client providing userId
/// @param userId userId with which to create sinch client
/// @param completion Blcok to be called when client was create or error happened
- (void)createClientWithUserId:(NSString *)userId completion:(ErrorCompletion)completion;

/// Call to start outgoing call
/// @param destination Remote userId
/// @param completion Blcok to be called if call transaction successfully executed with CallKit
- (void)startOutgoingCallTo:(NSString *)destination completion:(CallStartedCompletion)completion;

/// Call to end current outgoing call
/// @param call Call to end
- (void)endCall:(id<SINCall>)call;

/// Use this method to add call event observer
/// @param observer  Object conforming to
- (void)addObserver:(id<SINCallKitMediatorObserver>)observer;

/// Use this method to stop listening for call events
/// @param observer Object previously pased to addObserver:
- (void)removeObserver:(id<SINCallKitMediatorObserver>)observer;

@end

NS_ASSUME_NONNULL_END
